package mail

import (
	"fmt"
	"log"
	"net/mail"
	"os"

	"github.com/jhillyerd/go.enmime"
)

func MailParser(location string) map[string]string {
	// MailParser: parser e-mail

	file, errf := os.Open(location)
	msg, errm := mail.ReadMessage(file)        // Read email using Go's net/mail
	mime, errmine := enmime.ParseMIMEBody(msg) // Parse message body with enmime

	if errf != nil || errm != nil || errmine != nil {
		log.Fatal("Error mailParser: ", errf, errm, errmine)
	}

	data := make(map[string]string)

	// Headers ProxyMail
	fmt.Printf("proxyMail: %v\n", mime.GetHeader("x-original-to"))
	data["proxymail"] = mime.GetHeader("x-original-to")

	// Headers Date
	fmt.Printf("Date: %v\n", mime.GetHeader("Date"))
	data["date"] = mime.GetHeader("Date")

	// Headers are in the net/mail Message
	fmt.Printf("From: %v\n", msg.Header.Get("From"))

	fmt.Printf("From: %v\n", mime.GetHeader("From"))

	data["sender"] = mime.GetHeader("From")

	// enmime can decode quoted-printable headers
	fmt.Printf("Subject: %v\n", mime.GetHeader("Subject"))

	data["subject"] = mime.GetHeader("Subject")

	// The plain text body is available as mime.Text
	fmt.Printf("Text Body:  %v chars\n", len(mime.Text))

	fmt.Printf("Text Body: %s\n", mime.Text)

	data["content"] = mime.Text

	// The HTML body is stored in mime.Html
	fmt.Printf("HTML Body: %v chars\n", len(mime.Html))

	// mime.Inlines is a slice of inlined attacments
	fmt.Printf("Inlines: %v\n", len(mime.Inlines))

	// mime.Attachments contains the non-inline attachments
	fmt.Printf("Attachments: %v\n", len(mime.Attachments))

	return data
}
