package model

import (
	"log"
	"os"
	"time"

	"github.com/joho/godotenv"

	"gopkg.in/mgo.v2"
)

var mgoSession *mgo.Session

type (
	// Mail : Model for mail
	Mail struct {
		Subject     string
		Sender      string
		Proxymail   string
		Date        string
		Filename    string
		Attachments string
		Content     string
		Status      string
		CreatedAt   string
	}
)

func GetMongoSession() *mgo.Session {
	// GetMongoSession : Creates a new session if mgoSession is nil i.e there is no active mongo session.
	if mgoSession == nil {
		var err error
		err = godotenv.Load()
		if err != nil {
			log.Fatal("Error loading .env file")
		}
		mgoSession, err = mgo.Dial(os.Getenv("MONGO_HOST") + ":" + os.Getenv("MONGO_PORT"))
		if err != nil {
			log.Fatal("Failed to start the Mongo session")
		}
		// Optional. Switch the session to a monotonic behavior.
		mgoSession.SetMode(mgo.Monotonic, true)
	}
	return mgoSession.Clone()
}

func InsertMail(mail map[string]string) {
	// InsertMail : Insert data to Mail

	sessionCopy := mgoSession.Copy()
	defer sessionCopy.Close()
	c := sessionCopy.DB("test").C("mail")

	err := c.Insert(&Mail{
		mail["subject"],
		mail["sender"],
		mail["proxymail"],
		mail["date"],
		"",
		"",
		mail["content"],
		"cur",
		time.Now().Local().Format("2006-01-02"),
	})
	if err != nil {
		log.Fatal("Error insertMail: ", err)
	}
}

// func getMail(mongoSession *mgo.Session) {
// 	sessionCopy := mongoSession.Copy()
// 	defer sessionCopy.Close()
// 	c := sessionCopy.DB("test").C("mail")
// 	result := Mail{}
// 	err := c.Find(bson.M{"from": "Ale"}).One(&result)
// 	if err != nil {
// 		log.Fatal(err)
// 	}

// 	fmt.Println("From:", result.From)
// 	fmt.Println("Content:", result.Content)
// }
